---
title: <span class="badge object-type-scalar"></span> Gray
---
# <span class="badge object-type-scalar"></span> Gray

Radiation: Gray (Gy)

## Definition

```python
# Radiation: Gray (Gy)
Gray: typing.Literal["radgy"] = "radgy"
```
